@@ -1,6 +1,7 @@
-from pytiers.core import PitchTier, Point
+from pytiers.core import PitchTier, DurationTier, Point
+import os
 
-def read_PitchTier(file):
+def read_Tier(file):
     
     def findby_initial_str(strs, initial_str):
         for this_str in strs:
@@ -24,9 +25,23 @@ def read_PitchTier(file):
     
     with open(file, 'r') as f:
         strs = f.readlines()
+    
+    tier_type = strs[1].split(' ')[-1].replace('"', '').replace('\n', '')
+    original_dir = os.path.dirname(file)
+    file_name = os.path.basename(file).split('.')[0]
 
-    pt = PitchTier(str_to_float(findby_initial_str(strs, 'xmin')),
-                   str_to_float(findby_initial_str(strs, 'xmax')))
+    if tier_type=='PitchTier':
+        tier = PitchTier(str_to_float(findby_initial_str(strs, 'xmin')),
+                         str_to_float(findby_initial_str(strs, 'xmax')),
+                         name=file_name,
+                         original_dir=original_dir)
+    elif tier_type=='DurationTier':
+        tier = DurationTier(str_to_float(findby_initial_str(strs, 'xmin')),
+                            str_to_float(findby_initial_str(strs, 'xmax')),
+                            name=file_name,
+                            original_dir=original_dir)
+    else:
+        raise Exception(f'{tier_type} is not supported.')
     
     point_num = str_to_float(findby_initial_str(strs, 'points:'))
     
@@ -38,6 +53,6 @@ def read_PitchTier(file):
             
             this_point = Point(time, value, point_index)
             
-            pt._add_point_from_file(this_point)
+            tier._add_point_from_file(this_point)
        
-    return pt
\ No newline at end of file
+    return tier
\ No newline at end of file
